<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\MappedSuperclass
 * @ORM\Table(name="dedi_blog_article_translation")
 * @UniqueEntity(fields={"slug"})
 */
class ArticleTranslation extends AbstractReferableTranslation implements ArticleTranslationInterface
{
    /**
     * @ORM\Column(type="integer", nullable=false)
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected ?int $id = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="article_translation_slug")
     * @Gedmo\Slug(fields={"title"}, unique=true)
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $slug = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="article_translation_title")
     * @Assert\NotBlank(groups={"default", "sylius"})
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $title = null;

    /**
     * @ORM\Column(type="text", nullable=false, name="article_translation_content")
     * @Assert\NotBlank(groups={"default", "sylius"})
     */
    protected ?string $content = null;

    /** @ORM\Column(type="text", nullable=true, name="article_translation_description") */
    protected ?string $description = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(?string $slug): self
    {
        $this->slug = $slug;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(?string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(?string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }
}
